@@ -1,5 +1,5 @@
 from sqlalchemy import Column, Integer, String, Float, Boolean, ForeignKey, Date, DateTime
-from sqlalchemy.orm import relationship
+from sqlalchemy.orm import relationship, validates
 
 from univer_db.orm import get_base
 
@@ -542,9 +542,8 @@ class ControllTypeControllLink(Base):
 
 class MarkType(Base):
     """
-    Модель "Тип оценки"
+    Тип оценки
     """
-
     __tablename__ = 'univer_mark_type'
 
     # Идентификатор
@@ -562,14 +561,60 @@ class MarkType(Base):
     # GPA
     gpa = Column('mark_type_gpa', Float)
 
-    # ???
+    # Наименование
+    name_ru = Column('mark_text_ru', String(50))
+    name_kz = Column('mark_text_kz', String(50))
+    name_en = Column('mark_text_en', String(50))
+
+    # Короткое наименование
+    short_name_ru = Column('mark_text_short_ru', String(10))
+    short_name_kz = Column('mark_text_short_kz', String(10))
+    short_name_en = Column('mark_text_short_en', String(10))
+
+    # Статус
+    # Возможные значения:
+    # - 1 (Активный)
+    # - 2 (Архивный)
+    status = Column('mark_status', Integer)
+
+    @validates('status')
+    def validate_status(self, key, value):
+        """
+        Значением status могут быть следующие значения:
+        - 1 (Активный)
+        - 2 (Архивный)
+        """
+        assert value in [1, 2]
+        return value
+
+    # Неизвестное поле
     arg = Column('mark_type_arg', Integer)
 
+    # Неудаляемый
+    # Эти типы оценок невозможно удалить через интерфейс Univer
+    # Возможные значения:
+    # - 0 (Можно удалить)
+    # - 1 (Нельзя удалить)
+    undeletable = Column(Integer)
+
+    @validates('undeletable')
+    def validate_undeletable(self, key, value):
+        """
+        Значением undeletable могут быть следующие значения:
+        - 0 (Можно удалить)
+        - 1 (Нельзя удалить)
+        """
+        assert value in [0, 1]
+        return value
+
+    # Неизвестное поле
+    ects_symbol = Column('mark_type_ects_symbol', String(10))
+
     def __repr__(self):
-        return '<MarkType {}>'.format(self)
+        return f'<MarkType {self} (id={self.id} gpa={self.gpa} status={self.status})>'
 
     def __str__(self):
-        return '{} ({})'.format(self.symbol, self.gpa)
+        return f'{self.name_ru}'
 
 
 class Progress(Base):
