@@ -1,4 +1,4 @@
-from sqlalchemy import Column, Integer, String, Float, Boolean, ForeignKey, Date, DateTime
+from sqlalchemy import Column, Integer, String, Float, Boolean, ForeignKey, Date, DateTime, REAL
 from sqlalchemy.orm import relationship
 
 from univer_db.orm import get_base
@@ -69,32 +69,58 @@ class SheetType(Base):
 
 class SheetResult(Base):
     """
-    Модель "Результаты ведомости"
+    Результат ведомости
     """
-
     __tablename__ = 'univer_sheet_result'
 
+    # Ведомость
     sheet_id = Column(ForeignKey('univer_sheet.sheet_id'), primary_key=True)
     sheet = relationship('Sheet')
+
+    # Дисциплина
     subject_id = Column(ForeignKey('univer_subject.subject_id'))
     subject = relationship('Subject')
+
+    # Преподаватель
     teacher_id = Column(ForeignKey('univer_teacher.teacher_id'))
     teacher = relationship('Teacher')
+
+    # Академический год
     academ_year = Column(Integer)
+
+    # Семестр академического кода
     semester = Column('semestr', Integer)
-    control = Column(Integer, primary_key=True)
+
+    # Контроль
+    control_id = Column('control', ForeignKey(
+        'univer_control.control_id'), primary_key=True)
+    control = relationship('Control')
+
+    # Студент
     student_id = Column(ForeignKey(
         'univer_students.students_id'), primary_key=True)
     student = relationship('Student')
-    result = Column(Float)
+
+    # Результат
+    result = Column(REAL)
+
+    # Неизвестное поле
     date_keep = Column(DateTime)
+
+    # Неизвестное поле
     P_P = Column(Integer)
+
+    # Общий семестр
     n_seme = Column(Integer)
+
+    # Неизвестное поле
     mark_sheet_result = Column(Integer)
+
+    # Неизвестное поле
     retake_type = Column(Integer)
 
     def __repr__(self):
-        return '<SheetResult {} (sheet_id={})>'.format(self, self.sheet_id)
+        return f'<SheetResult {self} (result={self.result})>'
 
     def __str__(self):
-        return str(self.sheet_id)
+        return f'{self.sheet_id}'
